@@ -1,4 +1,4 @@
-demg <- function(x, mu=0, sigma=1, lambda=1)
+demg <- function(x, mu=0, sigma=1, lambda=1, log=FALSE)
 {
   l <- max(length(x), length(mu), length(sigma), length(lambda))
   
@@ -10,9 +10,18 @@ demg <- function(x, mu=0, sigma=1, lambda=1)
   if(min(sigma) <= 0.0)       {stop("Sigma must be greater than zero") }
   if(min(lambda) <= 0.0)      {stop("Lambda must be greater than zero")}
 
-  erfc <- pnorm((mu+lambda*sigma*sigma-x)/ sigma , lower = FALSE)
-  result <- exp(lambda/2 * (2*mu+lambda*sigma*sigma-2*x)) * Re(erfc) * lambda
+  erfc <- pnorm((mu+lambda*sigma*sigma-x)/ sigma , lower.tail = FALSE, log.p=log)
+  
+  if(log)
+  {
+    result <- lambda/2 * (2*mu+lambda*sigma*sigma-2*x) + Re(erfc) + log(lambda)
+  } else {
+    result <- exp(lambda/2 * (2*mu+lambda*sigma*sigma-2*x)) * Re(erfc) * lambda
+  }
+  
+  # Too small to compute, zero it
   result[is.nan(result)] <- 0
+
   result
 }
 
