@@ -1,4 +1,4 @@
 remg <- function(n, mu=0, sigma=1, lambda=1)
 {
-  qemg(runif(n), mu, sigma, lambda)
+  rnorm(n, mu, sigma) + rexp(n, lambda)
 }
\ No newline at end of file
